@@ -1174,6 +1174,23 @@ find_window_at_pointer (GSManager *manager)
         return window;
 }
 
+void
+gs_manager_show_message (GSManager  *manager,
+                         const char *summary,
+                         const char *body,
+                         const char *icon)
+{
+        GSWindow *window;
+
+        g_return_if_fail (GS_IS_MANAGER (manager));
+
+        /* Find the GSWindow that contains the pointer */
+        window = find_window_at_pointer (manager);
+        gs_window_show_message (window, summary, body, icon);
+
+        gs_manager_request_unlock (manager);
+}
+
 static gboolean
 manager_maybe_grab_window (GSManager *manager,
                            GSWindow  *window)
@@ -1478,9 +1495,6 @@ on_screen_monitors_changed (GdkScreen *screen,
                         gs_manager_create_window_for_monitor (manager, screen, i);
                 }
         } else {
-
-                gdk_x11_grab_server ();
-
                 /* remove the extra windows */
                 l = manager->priv->windows;
                 while (l != NULL) {
@@ -1498,16 +1512,6 @@ on_screen_monitors_changed (GdkScreen *screen,
                         }
                         l = next;
                 }
-
-                /* make sure there is a lock dialog on a connected monitor,
-                 * and that the keyboard is still properly grabbed after all
-                 * the windows above got destroyed*/
-                if (n_windows > n_monitors) {
-                        gs_manager_request_unlock (manager);
-                }
-
-                gdk_flush ();
-                gdk_x11_ungrab_server ();
         }
 }
 
